@@ -44,6 +44,16 @@ extern "C" {
 
 }
 
+#ifndef _
+#include <libintl.h>
+#define _(x) gettext(x)
+#ifdef gettext_noop
+#define N_(String) gettext_noop (String)
+#else
+#define N_(String) (String)
+#endif
+#endif
+
 
 #include "gmconf.h"
 #include "gmcontacts.h"
@@ -213,7 +223,7 @@ gmcontact_new ()
   contact->comment = NULL;
   contact->software = NULL;
   contact->email = NULL;
-  contact->state = 0;
+  contact->state = CONTACT_AVAILABLE;
   contact->video_capable = FALSE;
   contact->uid =  
     g_strdup ((const gchar *) e_contact_get_const (E_CONTACT (econtact), 
@@ -224,6 +234,29 @@ gmcontact_new ()
 }
 
 
+GmContact *
+gmcontact_copy (GmContact *orig)
+{
+  GmContact *contact = NULL;
+
+  contact = g_new (GmContact, 1);
+
+  contact->fullname = g_strdup (orig->fullname);
+  contact->categories = g_strdup (orig->categories);
+  contact->url = g_strdup (orig->url);
+  contact->location = g_strdup (orig->location);
+  contact->speeddial = g_strdup (orig->speeddial);
+  contact->comment = g_strdup (orig->comment);
+  contact->software = g_strdup (orig->software);
+  contact->email = g_strdup (orig->email);
+  contact->state = orig->state;
+  contact->video_capable = orig->video_capable;
+  contact->uid = g_strdup (orig->uid); 
+
+  return contact;
+}
+
+
 void
 gmcontact_delete (GmContact *contact)
 {
@@ -251,6 +284,8 @@ gm_addressbook_new ()
   ESourceList *list = NULL;
   ESourceGroup *source_group = NULL;
   ESource *source = NULL;
+  gchar *source_dir = NULL;
+  ESourceGroup *on_this_computer = NULL;
 
   addressbook = g_new (GmAddressbook, 1);
   
@@ -262,8 +297,27 @@ gm_addressbook_new ()
   source = e_source_new ("", "");
   source_group = gnomemeeting_addressbook_get_local_source_group (&list);
 
+  if (!source_group) {
+
+    source_dir = g_strdup_printf ("file://%s/.evolution/addressbook/local", 
+				  g_get_home_dir ());
+    on_this_computer = e_source_group_new (_("On This Computer"), source_dir);
+    e_source_list_add_group (list, on_this_computer, -1);
+    source = e_source_new ("", "");
+
+    e_source_set_name (source, _("Personal"));
+    e_source_set_relative_uri (source, "system");
+    e_source_set_group (source, on_this_computer);
+    e_source_group_add_source (on_this_computer, source, -1); 
+
+    e_source_list_sync (list, NULL);
+    g_free (source_dir);
+
+    source_group = gnomemeeting_addressbook_get_local_source_group (&list);
+  }
+
   if (source_group) {
-  
+
     e_source_set_relative_uri (source, e_source_peek_uid (source));
     e_source_set_group (source, source_group);
     addressbook->name = NULL;
@@ -359,11 +413,11 @@ GSList *
 gnomemeeting_local_addressbook_get_contacts (GmAddressbook *addbook,
 					     int & nbr,
 					     gboolean partial_match,
-					     gchar *fullname,
-					     gchar *url,
-					     gchar *categorie,
-					     gchar *location,
-					     gchar *speeddial)
+					     const gchar *fullname,
+					     const gchar *url,
+					     const gchar *categorie,
+					     const gchar *location,
+					     const gchar *speeddial)
 {
   EBook *ebook = NULL;
   EBookQuery *query = NULL;
