@@ -104,11 +104,11 @@ GSList *
 gnomemeeting_addressbook_get_contacts (GmAddressbook *addressbook,
 				       int &nbr,
 				       gboolean partial_match,
-				       gchar *fullname,
-				       gchar *url,
-				       gchar *categorie,
-				       gchar *location,
-				       gchar *speeddial)
+				       const gchar *fullname,
+				       const gchar *url,
+				       const gchar *categorie,
+				       const gchar *location,
+				       const gchar *speeddial)
 {
   if (addressbook && !gnomemeeting_addressbook_is_local (addressbook)) 
     return gnomemeeting_remote_addressbook_get_contacts (addressbook,
