@@ -198,11 +198,11 @@ GSList *gnomemeeting_get_remote_addressbooks ();
 GSList *gnomemeeting_addressbook_get_contacts (GmAddressbook *addressbook,
 					       int &nbr,
 					       gboolean partial_match,
-                                               gchar *fullname,
-                                               gchar *url,
-                                               gchar *categorie,
-                                               gchar *location,
-					       gchar *speeddial);
+                                               const gchar *fullname,
+                                               const gchar *url,
+                                               const gchar *categorie,
+                                               const gchar *location,
+					       const gchar *speeddial);
 
 
 /* DESCRIPTION  : /
