@@ -68,12 +68,14 @@
 #include "winpaths.h"
 #endif
 
-static void dialog_response_cb (GtkWidget *, gint, gpointer);
+static void dialog_response_cb (GtkWidget *widget,
+				gint unused,
+				gpointer data);
 
 
 /* The GTK callbacks */
-static void dialog_response_cb (GtkWidget *w, 
-				gint, 
+static void dialog_response_cb (GtkWidget *widget,
+				gint unused,
 				gpointer data)
 {
   g_return_if_fail (data);
@@ -81,7 +83,7 @@ static void dialog_response_cb (GtkWidget *w,
 
   gm_druid_window_set_test_buttons_sensitivity (GTK_WIDGET (data), FALSE);
 
-  gtk_widget_hide (w);
+  gtk_widget_hide (widget);
 }
 
 
@@ -100,7 +102,7 @@ gnomemeeting_sound_daemons_suspend (void)
     esd_standby (esd_client);
     esd_close (esd_client);
   }
-  PThread::Current ()->Sleep (100); // FIXME dirty workaround for ESD bug
+  PThread::Current ()->Sleep (300); // FIXME dirty workaround for ESD bug
 #endif
 }
 
@@ -197,7 +199,7 @@ void GMSoundEvent::Main ()
 
       if (channel) {
 
-	channel->SetBuffers (640, 2);
+	channel->SetBuffers (320, 4);
 	
 	buffer.SetSize (wav->GetDataLength ());
 	memset (buffer.GetPointer (), '0', buffer.GetSize ());
@@ -302,7 +304,7 @@ void GMAudioRP::Main ()
     
     nbr_opened_channels++;
 
-    channel->SetBuffers (640, 2);
+    channel->SetBuffers (320, 4);
     
     while (!stop) {
       
@@ -390,7 +392,7 @@ void GMAudioRP::Main ()
 	  PThread::Current ()->Sleep (100);
       }
 
-      if (buffer_pos >= 80000)
+      if (buffer_pos >= 160000)
 	buffer_pos = 0;	
     }
   }
@@ -428,9 +430,9 @@ GMAudioRP::GetAverageSignalLevel (const short *buffer, int size)
 
 
 /* The Audio tester class */
-  GMAudioTester::GMAudioTester (gchar *m,
-				gchar *p,
-				gchar *r,
+  GMAudioTester::GMAudioTester (gchar *manager,
+				gchar *player,
+				gchar *recorder,
 				GMManager & endpoint)
   :PThread (1000, NoAutoDeleteThread), ep (endpoint)
 {
@@ -439,12 +441,12 @@ GMAudioRP::GetAverageSignalLevel (const short *buffer, int size)
   test_dialog = NULL;
   test_label = NULL;
   
-  if (m)
-    audio_manager = PString (m);
-  if (p)
-    audio_player = PString (p);
-  if (r)
-    audio_recorder = PString (r);
+  if (manager)
+    audio_manager = PString (manager);
+  if (player)
+    audio_player = PString (player);
+  if (recorder)
+    audio_recorder = PString (recorder);
   
   this->Resume ();
   thread_sync_point.Wait ();
@@ -482,7 +484,7 @@ void GMAudioTester::Main ()
 
   gnomemeeting_sound_daemons_suspend ();
   
-  buffer_ring = (char *) malloc (8000 /*Hz*/ * 5 /*s*/ * 2 /*16bits*/);
+  buffer_ring = (char *) malloc (16000 /*Hz*/ * 5 /*s*/ * 2 /*16bits*/);
 
   memset (buffer_ring, '0', sizeof (buffer_ring));
 
