@@ -750,12 +750,20 @@ class GMManager : public OpalManager
 
  public:
 
+  /* DESCRIPTION  :  Notifier called every minute to check for IP changes.
+   * BEHAVIOR     :  Update the listeners. 
+   * PRE          :  /
+   */
+  PDECLARE_NOTIFIER(PTimer, GMManager, OnIPChanged);
+
+
   /* DESCRIPTION  :  Notifier called after 30 seconds of no media.
    * BEHAVIOR     :  Clear the calls.
    * PRE          :  /
    */
   PDECLARE_NOTIFIER(PTimer, GMManager, OnNoIncomingMediaTimeout);
 
+  
 #if 0
   /* DESCRIPTION  :  Notifier called periodically to update details on ILS.
    * BEHAVIOR     :  Register, unregister the user from ILS or udpate his
@@ -764,6 +772,15 @@ class GMManager : public OpalManager
    */
   PDECLARE_NOTIFIER(PTimer, GMManager, OnILSTimeout);
 #endif
+  
+
+  /* DESCRIPTION  :  Notifier called periodically during calls.
+   * BEHAVIOR     :  Refresh the average audio signal display 
+   *                 if it is currently shown.
+   * PRE          :  /
+   */
+  PDECLARE_NOTIFIER(PTimer, GMManager, OnAvgSignalTimeout);
+
 
   /* DESCRIPTION  :  Notifier called periodically during calls.
    * BEHAVIOR     :  Refresh the statistics window of the Control Panel
@@ -778,17 +795,8 @@ class GMManager : public OpalManager
    *                 if IP Checking is enabled in the config database.
    * PRE          :  /
    */
-  PDECLARE_NOTIFIER(PTimer, GMManager, OnGatewayIPTimeout);
+  PDECLARE_NOTIFIER(PTimer, GMManager, OnGatewayIPTimeout);  
 
-  
-  /* DESCRIPTION  :  Notifier called every 2 seconds while waiting for an
-   *                 answer for an outging call.
-   * BEHAVIOR     :  Display an animation in the main winow and play a ring
-   *                 sound.
-   * PRE          :  /
-   */
-  PDECLARE_NOTIFIER(PTimer, GMManager, OnOutgoingCall);
-  
 
   GtkWidget *audio_transmission_popup;
   GtkWidget *audio_reception_popup;
@@ -799,9 +807,10 @@ class GMManager : public OpalManager
   CallingState calling_state; 
 
   PTimer ILSTimer;
+  PTimer AvgSignalTimer;
   PTimer RTPTimer;
   PTimer GatewayIPTimer;
-  PTimer OutgoingCallTimer;
+  PTimer IPChangedTimer;
   PTimer NoIncomingMediaTimer;
     
   BOOL ils_registered;
