@@ -90,6 +90,7 @@ GMSIPEndpoint::Init ()
 
 
   /* Timeouts */
+  SetAckTimeout (PTimeInterval (0, 32));
   SetPduCleanUpTimeout (PTimeInterval (0, 1));
   SetInviteTimeout (PTimeInterval (0, 6));
   SetNonInviteTimeout (PTimeInterval (0, 6));
@@ -479,6 +480,7 @@ GMSIPEndpoint::OnReceivedMESSAGE (OpalTransport & transport,
   if (j != P_MAX_INDEX && from.Find ('>') == P_MAX_INDEX)
     from += '>';
 
+  PWaitAndSignal m(msgDataMutex);
   last = msgData.GetAt (SIPURL (from).AsString ());
   if (!last || *last != pdu.GetMIME ().GetCallID ()) {
 
