@@ -64,6 +64,16 @@ struct _GmCallsHistoryWindow
 };
 typedef struct _GmCallsHistoryWindow GmCallsHistoryWindow;
 
+enum {
+
+  COLUMN_DATE,
+  COLUMN_NAME,
+  COLUMN_URL,
+  COLUMN_DURATION,
+  COLUMN_ENDREASON,
+  COLUMN_SOFTWARE,
+  NUM_COLUMNS_HISTORY
+};
 
 #define GM_CALLS_HISTORY_WINDOW(x) (GmCallsHistoryWindow *) (x)
 
@@ -76,7 +86,7 @@ typedef struct _GmCallsHistoryWindow GmCallsHistoryWindow;
  * BEHAVIOR     : Frees a GmCallsHistoryWindow and its content.
  * PRE          : A non-NULL pointer to a GmCallsHistoryWindow.
  */
-static void gm_chw_destroy (gpointer pointer);
+static void gm_chw_destroy (gpointer data);
 
 
 /* DESCRIPTION  : / 
@@ -84,7 +94,7 @@ static void gm_chw_destroy (gpointer pointer);
  * 		  used by the calls history GMObject.
  * PRE          : The given GtkWidget pointer must be a calls history GMObject.
  */
-static GmCallsHistoryWindow *gm_chw_get_chw (GtkWidget *);
+static GmCallsHistoryWindow *gm_chw_get_chw (GtkWidget *calls_history_window);
 
 
 /* DESCRIPTION  : / 
@@ -95,7 +105,7 @@ static GmCallsHistoryWindow *gm_chw_get_chw (GtkWidget *);
  * PRE          : The given GtkWidget pointer must point to the calls history
  * 		  window GMObject.
  */
-static GmContact *gm_chw_get_selected_contact (GtkWidget *);
+static GmContact *gm_chw_get_selected_contact (GtkWidget *calls_history_window);
 
 
 /* DESCRIPTION  : / 
@@ -103,7 +113,7 @@ static GmContact *gm_chw_get_selected_contact (GtkWidget *);
  * PRE          : The given GtkWidget pointer must point to the calls history
  * 		  window GMObject.
  */
-static GtkWidget *gm_chw_contact_menu_new (GtkWidget *);
+static GtkWidget *gm_chw_contact_menu_new (GtkWidget *calls_history_window);
 
 
 /* DESCRIPTION  : / 
@@ -111,7 +121,7 @@ static GtkWidget *gm_chw_contact_menu_new (GtkWidget *);
  * PRE          : The given GtkWidget pointer must point to the calls history
  * 		  window GMObject.
  */
-static void gm_chw_update (GtkWidget *);
+static void gm_chw_update (GtkWidget *calls_history_window);
 
 
 /* DESCRIPTION  : / 
@@ -119,68 +129,7 @@ static void gm_chw_update (GtkWidget *);
  * 		  indice.
  * PRE          : /
  */
-static gchar *gm_chw_get_conf_key (int);
-
-
-/* Callbacks */
-
-/* DESCRIPTION  :  This callback is called when the user has clicked the clear
- *                 button.
- * BEHAVIOR     :  Clears the corresponding calls list using the config DB.
- * PRE          :  data = the calls history window GMObject.
- */
-static void clear_button_clicked_cb (GtkButton *,
-				     gpointer);
-
-
-/* DESCRIPTION  :  This callback is called when the user has clicked the find
- *                 button.
- * BEHAVIOR     :  Hides the rows that do not contain the text in the search
- *                 entry.
- * PRE          :  data = the GtkNotebook containing the 3 lists of calls.
- */
-static void find_button_clicked_cb (GtkButton *,
-				    gpointer);
-
-
-/* DESCRIPTION  : / 
- * BEHAVIOR     : This callback is called when the user clicks on a contact.
- * 		  Displays a popup.
- * PRE          : A valid pointer to the calls history window GMObject.
- */
-static gint contact_clicked_cb (GtkWidget *w,
-				GdkEventButton *e,
-				gpointer data);
-
-
-/* DESCRIPTION  : / 
- * BEHAVIOR     : This callback is called when the user chooses to call 
- * 	  	  a contact using the menu.
- * PRE          : The calls history window as argument.  
- */
-static void call_contact1_cb (GtkWidget *,
-			      gpointer);
-
-
-/* DESCRIPTION  : / 
- * BEHAVIOR     : This callback is called when the user chooses to call 
- * 	  	  a contact by double-clicking on it.
- * PRE          : The calls history window as argument.  
- */
-static void call_contact2_cb (GtkTreeView *,
-			      GtkTreePath *,
-			      GtkTreeViewColumn *,
-			      gpointer);
-
-
-/* DESCRIPTION  : / 
- * BEHAVIOR     : This callback is called when the user chooses to add the
- * 		  contact in the address book.
- * 		  It presents the dialog to edit a contact. 
- * PRE          : The gpointer must point to the calls history window. 
- */
-static void add_contact_cb (GtkWidget *,
-			    gpointer);
+static gchar *gm_chw_get_conf_key (int calltype);
 
 
 /* DESCRIPTION  :  This function is called when the user drops the contact.
@@ -191,12 +140,73 @@ static GmContact *dnd_get_contact (GtkWidget *widget,
 				   gpointer data);
 
 
+/* Callbacks */
+
+/* DESCRIPTION  :  This callback is called when the user has clicked the clear
+ *                 button.
+ * BEHAVIOR     :  Clears the corresponding calls list using the config DB.
+ * PRE          :  data = the calls history window GMObject.
+ */
+static void clear_button_clicked_cb (GtkButton *widget,
+				     gpointer data);
+
+
+/* DESCRIPTION  :  This callback is called when the user has clicked the find
+ *                 button.
+ * BEHAVIOR     :  Hides the rows that do not contain the text in the search
+ *                 entry.
+ * PRE          :  data = the GtkNotebook containing the 3 lists of calls.
+ */
+static void find_button_clicked_cb (GtkButton *widget,
+				    gpointer data);
+
+
+/* DESCRIPTION  : / 
+ * BEHAVIOR     : This callback is called when the user clicks on a contact.
+ * 		  Displays a popup.
+ * PRE          : A valid pointer to the calls history window GMObject.
+ */
+static gint contact_clicked_cb (GtkWidget *widget,
+				GdkEventButton *event,
+				gpointer data);
+
+
+/* DESCRIPTION  : / 
+ * BEHAVIOR     : This callback is called when the user chooses to call 
+ * 	  	  a contact using the menu.
+ * PRE          : The calls history window as argument.  
+ */
+static void call_contact1_cb (GtkWidget *widget,
+			      gpointer data);
+
+
+/* DESCRIPTION  : / 
+ * BEHAVIOR     : This callback is called when the user chooses to call 
+ * 	  	  a contact by double-clicking on it.
+ * PRE          : The calls history window as argument.  
+ */
+static void call_contact2_cb (GtkTreeView *tree_view,
+			      GtkTreePath *arg1,
+			      GtkTreeViewColumn *arg2,
+			      gpointer data);
+
+
+/* DESCRIPTION  : / 
+ * BEHAVIOR     : This callback is called when the user chooses to add the
+ * 		  contact in the address book.
+ * 		  It presents the dialog to edit a contact. 
+ * PRE          : The gpointer must point to the calls history window. 
+ */
+static void add_contact_cb (GtkWidget *widget,
+			    gpointer data);
+
+
 /* DESCRIPTION  :  This function is called to compare 1 GmContact to an URL.
  * BEHAVIOR     :  Returns 0 if both URLs are equal.
  * PRE          :  /
  */
-static gint contact_compare_cb (gconstpointer a,
-				gconstpointer b);
+static gint contact_compare_cb (gconstpointer contact,
+				gconstpointer url);
 
 
 /* DESCRIPTION  :  This callback is called when one of the calls history 	 *                 config value changes. 	 
@@ -205,9 +215,9 @@ static gint contact_compare_cb (gconstpointer a,
  * PRE          :  A valid pointer to the calls history window GMObject. 	 
  */ 	 
 static void 	 
-calls_history_changed_nt (gpointer,
-			  GmConfEntry *,
-			  gpointer); 
+calls_history_changed_nt (gpointer id,
+			  GmConfEntry *entry,
+			  gpointer data);
 
 
 /* Implementation */
@@ -262,8 +272,8 @@ gm_chw_get_selected_contact (GtkWidget *calls_history_window)
     contact = gmcontact_new ();
 
     gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 
-			1, &contact->fullname,
-			2, &contact->url,
+			COLUMN_NAME, &contact->fullname,
+			COLUMN_URL, &contact->url,
 			-1);
   }
   
@@ -404,7 +414,7 @@ dnd_get_contact (GtkWidget *widget,
 
 
 static void
-clear_button_clicked_cb (GtkButton *b, 
+clear_button_clicked_cb (GtkButton *widget, 
 			 gpointer data)
 {
   GmCallsHistoryWindow *chw  = NULL;
@@ -424,9 +434,9 @@ clear_button_clicked_cb (GtkButton *b,
 
 
 static void
-find_button_clicked_cb (GtkButton *b, 
+find_button_clicked_cb (GtkButton *widget,
 			gpointer data)
-{ 
+{
   GmCallsHistoryWindow *chw = NULL;
 
   GtkListStore *list_store = NULL;
@@ -469,10 +479,10 @@ find_button_clicked_cb (GtkButton *b,
       removed = FALSE;
       gtk_tree_model_get (GTK_TREE_MODEL (list_store),
 			  &iter,
-			  0, &date,
-			  1, &remote_user,
-			  4, &end_reason,
-			  5, &software,
+			  COLUMN_DATE, &date,
+			  COLUMN_NAME, &remote_user,
+			  COLUMN_ENDREASON, &end_reason,
+			  COLUMN_SOFTWARE, &software,
 			  -1);
 
       if (!(PString (date).Find (entry_text) != P_MAX_INDEX
@@ -498,21 +508,21 @@ find_button_clicked_cb (GtkButton *b,
 
 
 static gint
-contact_clicked_cb (GtkWidget *w,
-		    GdkEventButton *e,
+contact_clicked_cb (GtkWidget *widget,
+		    GdkEventButton *event,
 		    gpointer data)
 {
   GtkWidget *menu = NULL;
   
   g_return_val_if_fail (data != NULL, FALSE);
 
-  if (e->type == GDK_BUTTON_PRESS || e->type == GDK_KEY_PRESS) {
+  if (event->type == GDK_BUTTON_PRESS || event->type == GDK_KEY_PRESS) {
 
-    if (e->button == 3) {
+    if (event->button == 3) {
 
       menu = gm_chw_contact_menu_new (GTK_WIDGET (data));
       gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
-		      e->button, e->time);
+		      event->button, event->time);
       g_signal_connect (G_OBJECT (menu), "hide",
 			GTK_SIGNAL_FUNC (g_object_unref), (gpointer) menu);
       g_object_ref (G_OBJECT (menu));
@@ -525,7 +535,7 @@ contact_clicked_cb (GtkWidget *w,
 
 
 static void
-call_contact1_cb (GtkWidget *w,
+call_contact1_cb (GtkWidget *widget,
 		  gpointer data)
 {
   GmContact *contact = NULL;
@@ -559,7 +569,7 @@ call_contact2_cb (GtkTreeView *tree_view,
 
 
 static void
-add_contact_cb (GtkWidget *w,
+add_contact_cb (GtkWidget *widget,
 		gpointer data)
 {
   GmContact *contact = NULL;
@@ -587,19 +597,19 @@ add_contact_cb (GtkWidget *w,
 
 
 static gint 
-contact_compare_cb (gconstpointer a,
-		    gconstpointer b)
+contact_compare_cb (gconstpointer contact,
+		    gconstpointer url)
 {
-  GmContact *aa = NULL;
+  GmContact *gmcontact = NULL;
   
-  if (!a || !b)
+  if (!contact || !url)
     return 1;
   
-  aa = GM_CONTACT (a);
+  gmcontact = GM_CONTACT (contact);
   
-  if (aa->url && b) {
+  if (gmcontact->url && url) {
   
-    if (GMURL (aa->url) == GMURL ((char *) b))
+    if (GMURL (gmcontact->url) == GMURL ((char *) url))
       return 0;
     else
       return 1;
@@ -650,7 +660,7 @@ gm_calls_history_window_new ()
   GtkListStore *list_store = NULL;
 
   gchar *conf_key = NULL;
-  gchar *label_text [3] =
+  const gchar *label_text [3] =
     {N_("Received Calls"), N_("Placed Calls"), N_("Missed Calls")};
   label_text [0] = gettext (label_text [0]);
   label_text [1] = gettext (label_text [1]);
@@ -658,7 +668,7 @@ gm_calls_history_window_new ()
 
   
   window = gtk_dialog_new ();
-  gtk_dialog_add_button (GTK_DIALOG (window), GTK_STOCK_CLOSE, 0);
+  gtk_dialog_add_button (GTK_DIALOG (window), GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL);
 
   g_object_set_data_full (G_OBJECT (window), "window_name",
 			  g_strdup ("calls_history_window"), g_free);
@@ -709,7 +719,7 @@ gm_calls_history_window_new ()
     column = gtk_tree_view_column_new_with_attributes (_("Date"),
 						       renderer,
 						       "text", 
-						       0,
+						       COLUMN_DATE,
 						       NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (chw->chw_history_tree_view [i]), column);
     
@@ -717,7 +727,7 @@ gm_calls_history_window_new ()
     column = gtk_tree_view_column_new_with_attributes (_("Remote User"),
 						       renderer,
 						       "text", 
-						       1,
+						       COLUMN_NAME,
 						       NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (chw->chw_history_tree_view [i]), column);
     g_object_set (G_OBJECT (renderer), "weight", "bold", NULL);
@@ -726,7 +736,7 @@ gm_calls_history_window_new ()
     column = gtk_tree_view_column_new_with_attributes (_("Call Duration"),
 						       renderer,
 						       "text", 
-						       3,
+						       COLUMN_DURATION,
 						       NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (chw->chw_history_tree_view [i]), column);
     if (i == 2)
@@ -736,7 +746,7 @@ gm_calls_history_window_new ()
     column = gtk_tree_view_column_new_with_attributes (_("Call End Reason"),
 						       renderer,
 						       "text", 
-						       4,
+						       COLUMN_ENDREASON,
 						       NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (chw->chw_history_tree_view [i]), column);
     g_object_set (G_OBJECT (renderer), "style", PANGO_STYLE_ITALIC, NULL);
@@ -745,7 +755,7 @@ gm_calls_history_window_new ()
     column = gtk_tree_view_column_new_with_attributes (_("Software"),
 						       renderer,
 						       "text", 
-						       5,
+						       COLUMN_SOFTWARE,
 						       NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (chw->chw_history_tree_view [i]), column);
     g_object_set (G_OBJECT (renderer), "style", PANGO_STYLE_ITALIC, NULL);
@@ -826,7 +836,7 @@ gm_calls_history_window_new ()
 
 
 void
-gm_calls_history_add_call (int i,
+gm_calls_history_add_call (int calltype,
 			   const char *remote_user,
 			   const char *ip,
 			   const char *duration,
@@ -852,7 +862,7 @@ gm_calls_history_add_call (int i,
 		     reason ? reason : "",
 		     software ? software : "");
   
-  conf_key = gm_chw_get_conf_key (i);
+  conf_key = gm_chw_get_conf_key (calltype);
 
   calls_list = gm_conf_get_string_list (conf_key);
   calls_list = g_slist_append (calls_list, (gpointer) call_data);
@@ -870,21 +880,21 @@ gm_calls_history_add_call (int i,
 
 
 void 
-gm_calls_history_clear (int i)
+gm_calls_history_clear (int calltype)
 {
   gchar *conf_key = NULL;
 
-  g_return_if_fail ((i >= 0 && i < MAX_VALUE_CALL));
+  g_return_if_fail ((calltype >= 0 && calltype < MAX_VALUE_CALL));
   
-  conf_key = gm_chw_get_conf_key (i);
+  conf_key = gm_chw_get_conf_key (calltype);
   gm_conf_set_string_list (conf_key, NULL);
   g_free (conf_key);
 }
 
 
 GSList *
-gm_calls_history_get_calls (int j,
-			    int n,
+gm_calls_history_get_calls (int calltype,
+			    int at_most,
 			    gboolean unique,
 			    gboolean reversed)
 {
@@ -903,8 +913,8 @@ gm_calls_history_get_calls (int j,
 
   for (int i = 0 ; i < MAX_VALUE_CALL ; i++) {
 
-    if (j == MAX_VALUE_CALL
-	|| j == i)  {
+    if (calltype == MAX_VALUE_CALL
+	|| calltype == i)  {
 
       conf_key = gm_chw_get_conf_key (i);
       calls_list = gm_conf_get_string_list (conf_key);
@@ -914,8 +924,8 @@ gm_calls_history_get_calls (int j,
       calls_list_iter = calls_list;
       while (calls_list_iter && calls_list_iter->data) {
 
-	if ((j == MAX_VALUE_CALL && n != -1) 
-	    || (j == i)) {
+	if ((calltype == MAX_VALUE_CALL && at_most != -1) 
+	    || (calltype == i)) {
 
 	  call_data = g_strsplit ((char *) calls_list_iter->data, "|", 0);
 
@@ -958,16 +968,16 @@ gm_calls_history_get_calls (int j,
 
   
   /* #INV: work_list contains the result, with unique items or not */
-  if (n == -1 || j == MAX_VALUE_CALL) // Return all values
+  if (at_most == -1 || calltype == MAX_VALUE_CALL) // Return all values
     result = work_list;
-  else { // Return the last n results
+  else { // Return the last at_most results
 
     if (reversed) work_list = g_slist_reverse (work_list);
     work_list_iter = work_list;
     while (work_list_iter && work_list_iter->data) {
 
       if (g_slist_position (work_list, work_list_iter) >=
-	  (int) g_slist_length (work_list) - n) {
+	  (int) g_slist_length (work_list) - at_most) {
 
 	result = 
 	  g_slist_append (result, 
