@@ -385,7 +385,6 @@ enum {
   COLUMN_CODEC_CLOCKRATE,
   COLUMN_CODEC_ENCODING_NAME,
   COLUMN_CODEC_SELECTABLE,
-  COLUMN_CODEC_COLOR,
   COLUMN_CODEC_NUMBER
 };
 
@@ -492,8 +491,6 @@ gm_codecs_list_new ()
                                                      COLUMN_CODEC_ENCODING_NAME,
                                                      NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
-  gtk_tree_view_column_add_attribute (column, renderer, "foreground", 
-                                      COLUMN_CODEC_COLOR);
   g_object_set (G_OBJECT (renderer), "weight", "bold", NULL);
 
   renderer = gtk_cell_renderer_text_new ();
@@ -503,8 +500,6 @@ gm_codecs_list_new ()
                                                      COLUMN_CODEC_BANDWIDTH,
                                                      NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
-  gtk_tree_view_column_add_attribute (column, renderer, "foreground", 
-                                      COLUMN_CODEC_COLOR);
 
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("Clock Rate"),
@@ -513,8 +508,6 @@ gm_codecs_list_new ()
                                                      COLUMN_CODEC_CLOCKRATE,
                                                      NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
-  gtk_tree_view_column_add_attribute (column, renderer, "foreground", 
-                                      COLUMN_CODEC_COLOR);
 
   return tree_view;
 }
@@ -917,7 +910,7 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
   devs = GnomeMeeting::Process ()->GetAudioOutpoutDevices ();
   array = devs.ToCharArray ();
   pw->sound_events_output =
-    gnome_prefs_string_option_menu_new (subsection, _("Alternative output device:"), array, SOUND_EVENTS_KEY "output_device", _("Select an alternative audio output device to use for sound events"), 0);
+    gnome_prefs_string_option_menu_new (subsection, _("Alternative output device:"), (const gchar **)array, SOUND_EVENTS_KEY "output_device", _("Select an alternative audio output device to use for sound events"), 0);
   free (array);
 }
 
@@ -954,7 +947,7 @@ gm_pw_init_network_page (GtkWidget *prefs_window,
   ifaces = GnomeMeeting::Process ()->GetInterfaces ();
   array = ifaces.ToCharArray ();
   pw->iface =
-    gnome_prefs_string_option_menu_new (subsection, _("Listen on:"), array, PROTOCOLS_KEY "interface", _("The network interface to listen on"), 0);
+    gnome_prefs_string_option_menu_new (subsection, _("Listen on:"), (const gchar **)array, PROTOCOLS_KEY "interface", _("The network interface to listen on"), 0);
   free (array);
 
 
@@ -963,7 +956,7 @@ gm_pw_init_network_page (GtkWidget *prefs_window,
     gnome_prefs_subsection_new (prefs_window, container,
                                 _("NAT Settings"), 2, 1);
 
-  gnome_prefs_int_option_menu_new (subsection, _("NAT Traversal Method:"), nat_method, NAT_KEY "method", _("Select the desired method for NAT traversal (STUN is strongly suggested)"), 1);
+  gnome_prefs_int_option_menu_new (subsection, _("NAT Traversal Method:"), (const gchar **)nat_method, NAT_KEY "method", _("Select the desired method for NAT traversal (STUN is strongly suggested)"), 1);
 
   gnome_prefs_entry_new (subsection, _("STUN Se_rver:"), NAT_KEY "stun_server", _("The STUN server to use for STUN Support."), 2, false);
 
@@ -1017,7 +1010,7 @@ gm_pw_init_h323_page (GtkWidget *prefs_window,
     gnome_prefs_subsection_new (prefs_window, container,
                                 _("DTMF Mode"), 1, 1);
 
-  gnome_prefs_int_option_menu_new (subsection, _("_Send DTMF as:"), capabilities, H323_KEY "dtmf_mode", _("This permits to set the mode for DTMFs sending. The values can be \"String\" (0), \"Tone\" (1), \"RFC2833\" (2), \"Q.931\" (3) (default is \"String\"). Choosing other values than \"String\" disables the Text Chat."), 0);
+  gnome_prefs_int_option_menu_new (subsection, _("_Send DTMF as:"), (const gchar **)capabilities, H323_KEY "dtmf_mode", _("This permits to set the mode for DTMFs sending. The values can be \"String\" (0), \"Tone\" (1), \"RFC2833\" (2), \"Q.931\" (3) (default is \"String\"). Choosing other values than \"String\" disables the Text Chat."), 0);
 }
 
 
@@ -1054,7 +1047,7 @@ gm_pw_init_sip_page (GtkWidget *prefs_window,
     gnome_prefs_subsection_new (prefs_window, container,
                                 _("DTMF Mode"), 1, 1);
 
-  gnome_prefs_int_option_menu_new (subsection, _("_Send DTMF as:"), capabilities, SIP_KEY "dtmf_mode", _("This permits to set the mode for DTMFs sending. The value can be \"RFC2833\" (0) only."), 0);
+  gnome_prefs_int_option_menu_new (subsection, _("_Send DTMF as:"), (const gchar **)capabilities, SIP_KEY "dtmf_mode", _("This permits to set the mode for DTMFs sending. The value can be \"RFC2833\" (0) only."), 0);
 }
 
 
@@ -1079,7 +1072,7 @@ gm_pw_init_audio_devices_page (GtkWidget *prefs_window,
   /* Add all the fields for the audio manager */
   devs = GnomeMeeting::Process ()->GetAudioPlugins ();
   array = devs.ToCharArray ();
-  gnome_prefs_string_option_menu_new (subsection, _("Audio plugin:"), array, AUDIO_DEVICES_KEY "plugin", _("The audio plugin that will be used to detect the devices and manage them."), 0);
+  gnome_prefs_string_option_menu_new (subsection, _("Audio plugin:"), (const gchar **)array, AUDIO_DEVICES_KEY "plugin", _("The audio plugin that will be used to detect the devices and manage them."), 0);
   free (array);
 
 
@@ -1092,14 +1085,14 @@ gm_pw_init_audio_devices_page (GtkWidget *prefs_window,
   devs = GnomeMeeting::Process ()->GetAudioOutpoutDevices ();
   array = devs.ToCharArray ();
   pw->audio_player =
-    gnome_prefs_string_option_menu_new (subsection, _("Output device:"), array, AUDIO_DEVICES_KEY "output_device", _("Select the audio output device to use"), 0);
+    gnome_prefs_string_option_menu_new (subsection, _("Output device:"), (const gchar **)array, AUDIO_DEVICES_KEY "output_device", _("Select the audio output device to use"), 0);
   free (array);
 
   /* The recorder */
   devs = GnomeMeeting::Process ()->GetAudioInputDevices ();
   array = devs.ToCharArray ();
   pw->audio_recorder =
-    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), array, AUDIO_DEVICES_KEY "input_device", _("Select the audio input device to use"), 2);
+    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, AUDIO_DEVICES_KEY "input_device", _("Select the audio input device to use"), 2);
   free (array);
 
 
@@ -1160,7 +1153,7 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
 
   devs = GnomeMeeting::Process ()->GetVideoPlugins ();
   array = devs.ToCharArray ();
-  gnome_prefs_string_option_menu_new (subsection, _("Video plugin:"), array, VIDEO_DEVICES_KEY "plugin", _("The video plugin that will be used to detect the devices and manage them"), 0);
+  gnome_prefs_string_option_menu_new (subsection, _("Video plugin:"), (const gchar **)array, VIDEO_DEVICES_KEY "plugin", _("The video plugin that will be used to detect the devices and manage them"), 0);
   free (array);
 
 
@@ -1172,7 +1165,7 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
   devs = GnomeMeeting::Process ()->GetVideoInputDevices ();
   array = devs.ToCharArray ();
   pw->video_device =
-    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), array, VIDEO_DEVICES_KEY "input_device", _("Select the video input device to use. If an error occurs when using this device a test picture will be transmitted."), 0);
+    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, VIDEO_DEVICES_KEY "input_device", _("Select the video input device to use. If an error occurs when using this device a test picture will be transmitted."), 0);
   free (array);
 
   /* Video Channel */
@@ -1182,7 +1175,7 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
   gnome_prefs_int_option_menu_new (subsection, _("Size:"), video_size, VIDEO_DEVICES_KEY "size", _("Select the transmitted video size: Normal (QCIF 176x144) or Large (CIF 352x288)"), 1);
 #endif
 
-  gnome_prefs_int_option_menu_new (subsection, _("Format:"), video_format, VIDEO_DEVICES_KEY "format", _("Select the format for video cameras (does not apply to most USB cameras)"), 2);
+  gnome_prefs_int_option_menu_new (subsection, _("Format:"), (const gchar **)video_format, VIDEO_DEVICES_KEY "format", _("Select the format for video cameras (does not apply to most USB cameras)"), 2);
 
   /* The file selector button */
   label = gtk_label_new (_("Image:"));
@@ -1695,7 +1688,7 @@ gm_prefs_window_update_interfaces_list (GtkWidget *prefs_window,
   /* The Video player */
   array = interfaces.ToCharArray ();
   gnome_prefs_string_option_menu_update (pw->iface,
-					 array,
+					 (const gchar **)array,
 					 PROTOCOLS_KEY "interface");
   free (array);
 }
@@ -1719,10 +1712,10 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window,
   /* The player */
   array = audio_output_devices.ToCharArray ();
   gnome_prefs_string_option_menu_update (pw->audio_player,
-					 array,
+					 (const gchar **)array,
 					 AUDIO_DEVICES_KEY "output_device");
   gnome_prefs_string_option_menu_update (pw->sound_events_output,
-					 array,
+					 (const gchar **)array,
 					 SOUND_EVENTS_KEY "output_device");
   free (array);
 
@@ -1730,7 +1723,7 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window,
   /* The recorder */
   array = audio_input_devices.ToCharArray ();
   gnome_prefs_string_option_menu_update (pw->audio_recorder,
-					 array,
+					 (const gchar **)array,
 					 AUDIO_DEVICES_KEY "input_device");
   free (array);
 
@@ -1738,7 +1731,7 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window,
   /* The Video player */
   array = video_input_devices.ToCharArray ();
   gnome_prefs_string_option_menu_update (pw->video_device,
-					 array,
+					 (const gchar **)array,
 					 VIDEO_DEVICES_KEY "input_device");
   free (array);
 }
@@ -1812,7 +1805,6 @@ gm_prefs_window_update_audio_codecs_list (GtkWidget *prefs_window,
 			    COLUMN_CODEC_CLOCKRATE, clockrate,
 			    COLUMN_CODEC_ENCODING_NAME, name,
 			    COLUMN_CODEC_SELECTABLE, "true",
-			    COLUMN_CODEC_COLOR, "black",
 			    -1);
 	if (selected_codec && !strcmp (selected_codec, (const char *) k [i]))
 	  gtk_tree_selection_select_iter (selection, &iter);
@@ -1846,7 +1838,6 @@ gm_prefs_window_update_audio_codecs_list (GtkWidget *prefs_window,
 			COLUMN_CODEC_CLOCKRATE, clockrate,
 			COLUMN_CODEC_ENCODING_NAME, name, 
 			COLUMN_CODEC_SELECTABLE, "true",
-			COLUMN_CODEC_COLOR, "black",
 			-1);
 
     if (selected_codec && !strcmp (selected_codec, (const char *) k [i]))
